@@ -876,5 +876,5 @@ utf8.len                    =
 'バイト位置 `i` から `j`（両方含む）の間に含まれるUTF-8文字の数を返す。'
 utf8.offset                 =
 '文字列 `s` における `n` 番目の文字が始まるバイト位置をを返す。`i` が指定された場合、`i` から数えたバイト位置を返す。'
-utf8.offset[55]             =
+utf8.offset['55']             =
 '文字列 `s` における `n` 番目の文字の位置を、2つの整数として返します（バイト位置 `i` から数えます）：その文字のエンコードが開始するバイトインデックスと終了するバイトインデックス。'
